@@ -25,8 +25,16 @@
 #ifndef __LUNAR_H__
 #define __LUNAR_H__  1
 
+#ifdef HAVE_CONFIG_H
+    #include <config.h>
+#endif
+
 #include <lunar/lunar-date.h>
-#include <lunar/lunar-calendar.h>
+
+#ifdef ENABLE_GTK
+    #include <lunar/lunar-calendar.h>
+#endif
+
 #include <lunar/lunar-main.h>
 
 #endif /*__LUNAR_H__ */
